@@ -68,19 +68,20 @@ describe 'tripleo::host::sriov::numvfs_persistence' do
     it 'configures persistence' do
       is_expected.to contain_file('/etc/sysconfig/allocate_vfs').with(
         :ensure  => 'file',
-        :content => "Hashbang\nset -eux
+        :content => "Hashbang\nset -ex
 set -o pipefail
 
 if [ \"eth0\" == \"$1\" ]
 then
   exec 1> >(logger -s -t $(basename $0)) 2>&1
+  vendor_id=\"$(cat /sys/class/net/eth0/device/vendor)\"
   if [ \"$(cat /sys/class/net/eth0/device/sriov_numvfs)\" == \"0\" ]
   then
     echo 10 > /sys/class/net/eth0/device/sriov_numvfs
   else
     exit 0
   fi
-  if [ \"$(cat /sys/class/net/eth0/device/vendor)\" == \"0x15b3\" ]
+  if [ $vendor_id == \"0x15b3\" ]
   then
     vfs_pci_list=$(grep PCI_SLOT_NAME /sys/class/net/eth0/device/virtfn*/uevent | cut -d'=' -f2)
     for pci in $vfs_pci_list
@@ -103,13 +104,6 @@ then
     /usr/sbin/devlink dev eswitch set pci/\"$interface_pci\" inline-mode transport
   fi
   /usr/sbin/ethtool -K eth0 hw-tc-offload on
-  if [ \"$(cat /sys/class/net/eth0/device/vendor)\" == \"0x15b3\" ]
-  then
-    for pci in $vfs_pci_list
-    do
-      echo \"$pci\" > /sys/bus/pci/drivers/mlx5_core/bind
-    done
-  fi
 fi\n[ \"eth1\" == \"\$1\" ] && echo 8 > /sys/class/net/eth1/device/sriov_numvfs\n",
         :group   => 'root',
         :mode    => '0755',
